@@ -2,7 +2,6 @@ from markdown_predictions.clean_data import PreProcessor
 from markdown_predictions.parse_data import LoadSalesData
 
 import pandas as pd
-import os
 
 
 def get_data(data_path: str) -> pd.DataFrame:
@@ -13,9 +12,6 @@ def get_data(data_path: str) -> pd.DataFrame:
     
     return pre_processor.df
 
-def get_path():
-    print(os.listdir())
-
 
 if __name__ == "__main__":
     print("HELLO 🥸🥝")
